pub fn image_to_array(image: &DynamicImage) -> Array3<u8>Expand description
Convert a DynamicImage to an HWC ndarray.
Panics
Panics if the array cannot be created from the image pixels (e.g. dimension mismatch).
pub fn image_to_array(image: &DynamicImage) -> Array3<u8>Convert a DynamicImage to an HWC ndarray.
Panics if the array cannot be created from the image pixels (e.g. dimension mismatch).